@@ -7,12 +7,20 @@ from warnings import warn
 try:
     from PIL import Image
 except ImportError:
-    warn("PIL is not found and it is used in some methods inside this library", ImportWarning)
+    warn(
+        "PIL is not found and it is used in some methods inside this library",
+        ImportWarning,
+    )
 
 from pronto_commons.utils import MB_BYTES
 
 
-def return_extension_from_base64(base64_string: str) -> Optional[str]:
+def return_extension_from_base64(*, base64_string: str) -> Optional[str]:
+    """Function to return the extension from a base64 image
+    :param str base64_string: The image represented as a base64 string
+    :rtype: Optional[str]
+    :return: The extension with a dot such as .png or None
+    """
     guessed = guess_type(base64_string)
     if guessed[0] is None:
         return None
@@ -23,10 +31,6 @@ def return_extension_from_base64(base64_string: str) -> Optional[str]:
     return guess_extension(guessed[0])
 
 
-
-
-
-
 def compress_image(
     *,
     image_bytes: io.BytesIO,
@@ -35,6 +39,7 @@ def compress_image(
 ) -> io.BytesIO:
     # The extension must be only the format such as jpeg, png, without a prefix-point
     extension = extension.lower()
+
     if extension == "jpg":
         # PIL IMAGE doesn't accept JPG
         extension = "jpeg"
@@ -47,25 +52,41 @@ def compress_image(
         quality_factor = (
             quality_factor * 100
         )  # The quality factor must be  multiple of 10
+        quality_factor = int(quality_factor)
         new_image_bytes = io.BytesIO()
         # Optimizing image
         image = Image.open(image_bytes)
         if extension == "jpeg" and image.mode != "RGB":
             # RGB is required to save as JPEG
             image = image.convert("RGB")
+        new_width = int(image.width * (quality_factor / 100))
+        new_heigth = int(image.height * (quality_factor / 100))
+
+        image = image.resize((new_width, new_heigth), Image.ANTIALIAS)
+
         image.save(
             new_image_bytes,
             format=extension,
             optimize=True,
-            quality=int(quality_factor),
+            quality=quality_factor,
         )
 
+        new_image_bytes.seek(0)
+
+        if new_image_bytes.getbuffer().nbytes > bytes_size:
+            # If the image is too small there is a bug, which will give us a not optimized image
+            image_bytes.seek(0)
+            return image_bytes
+
         new_image_bytes.seek(0)
         return new_image_bytes
 
 
-
-
-def convert_base64_to_image(base64_string: str) -> io.BytesIO:
+def convert_base64_to_image(*, base64_string: str) -> io.BytesIO:
+    """Function to convert a base64 image into bytes
+    :param str base64_string: The base64 image string
+    :rtype: io.BytesIO
+    :return: A bytes object, that represents the image
+    """
     encoded_data = base64_string.split(",")[1]
     return io.BytesIO(base64.b64decode(encoded_data))
