@@ -6,7 +6,9 @@ from typing import Dict, Optional, Tuple
 import jwt
 
 
-def encode_jwt(*, data: Dict, expiration_time_days: int, jwt_secret_key: str) -> Tuple[str, int]:
+def encode_jwt(
+    *, data: Dict, expiration_time_days: int, jwt_secret_key: str
+) -> Tuple[str, int]:
     data_copy = copy.deepcopy(data)
     expiration_time = datetime.datetime.utcnow() + datetime.timedelta(
         days=expiration_time_days
@@ -17,12 +19,13 @@ def encode_jwt(*, data: Dict, expiration_time_days: int, jwt_secret_key: str) ->
     return token, int(expiration_time.timestamp())
 
 
-def decode_jwt(*, jwt_token: str, jwt_secret_key: str, verify_exp: bool = False) -> Dict:
+def decode_jwt(
+    *, jwt_token: str, jwt_secret_key: str, verify_exp: bool = False
+) -> Dict:
     data = jwt.decode(
-        jwt_token, jwt_secret_key, algorithms=["HS256"], options={"verify_exp": verify_exp}
+        jwt_token,
+        jwt_secret_key,
+        algorithms=["HS256"],
+        options={"verify_exp": verify_exp},
     )
     return data
-
-
-
-
